mlbench_core.lr_scheduler
-------------------------
.. automodule:: mlbench_core.lr_scheduler
.. currentmodule:: mlbench_core.lr_scheduler

pytorch
~~~~~~~

.. automodule:: mlbench_core.lr_scheduler.pytorch
.. currentmodule:: mlbench_core.lr_scheduler.pytorch

SparsifiedSGDLR
+++++++++++++++

.. autoclass:: SparsifiedSGDLR
    :members:

SGDLR
+++++

.. autoclass:: SGDLR
    :members:


triangular_learning_rates
+++++++++++++++++++++++++

.. autofunction:: triangular_learning_rates

cyclical_learning_rates
+++++++++++++++++++++++

.. autofunction:: cyclical_learning_rates

multistep_learning_rates_with_warmup
++++++++++++++++++++++++++++++++++++

.. autofunction:: multistep_learning_rates_with_warmup


.. rubric:: References


.. bibliography:: lr_scheduler.bib
   :cited:


tensorflow
~~~~~~~~~~

.. automodule:: mlbench_core.lr_scheduler.tensorflow
.. currentmodule:: mlbench_core.lr_scheduler.tensorflow

manual_stepping
+++++++++++++++

.. autofunction:: manual_stepping
